summaryrefslogtreecommitdiff
path: root/src/mongo/db/service_context.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/service_context.h')
-rw-r--r--src/mongo/db/service_context.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/src/mongo/db/service_context.h b/src/mongo/db/service_context.h
index c1895bf4065..ad5af47e360 100644
--- a/src/mongo/db/service_context.h
+++ b/src/mongo/db/service_context.h
@@ -286,17 +286,19 @@ public:
}
/**
* Kills the operation "txn" with the code "killCode", if txn has not already been killed.
* Caller must own the lock on txn->getClient, and txn->getServiceContext() must be the same as
* this service context.
**/
- void killOperation(OperationContext* txn, ErrorCodes::Error killCode = ErrorCodes::Interrupted);
+ void killOperation(OperationContext* opCtx,
+ ErrorCodes::Error killCode = ErrorCodes::Interrupted);
/**
* Kills all operations that have a Client that is associated with an incoming user
* connection, except for the one associated with txn.
*/
- void killAllUserOperations(const OperationContext* txn, ErrorCodes::Error killCode);
+ void killAllUserOperations(const OperationContext* opCtx, ErrorCodes::Error killCode);
/**
* Registers a listener to be notified each time an op is killed.
@@ -286,17 +286,19 @@ public:
}
/**
- * Kills the operation "txn" with the code "killCode", if txn has not already been killed.
- * Caller must own the lock on txn->getClient, and txn->getServiceContext() must be the same as
+ * Kills the operation "opCtx" with the code "killCode", if opCtx has not already been killed.
+ * Caller must own the lock on opCtx->getClient, and opCtx->getServiceContext() must be the same
+ *as
* this service context.
**/
@@ -286,17 +286,19 @@ public:
/**
* Kills all operations that have a Client that is associated with an incoming user
- * connection, except for the one associated with txn.
+ * connection, except for the one associated with opCtx.
*/